Fix spelling of Identifier

Make google3 common typos stop complaining in the future.

Change-Id: Ib5156335afa691427dbe618c8b29797665cef35f
Reviewed-on: https://boringssl-review.googlesource.com/c/boringssl/+/66947
Auto-Submit: Bob Beck <bbe@google.com>
Commit-Queue: Bob Beck <bbe@google.com>
Reviewed-by: David Benjamin <davidben@google.com>
diff --git a/crypto/x509/internal.h b/crypto/x509/internal.h
index 1cdefaf..5018063 100644
--- a/crypto/x509/internal.h
+++ b/crypto/x509/internal.h
@@ -422,7 +422,7 @@
 // Signature algorithm functions.
 
 // x509_digest_sign_algorithm encodes the signing parameters of |ctx| as an
-// AlgorithmIdentifer and saves the result in |algor|. It returns one on
+// AlgorithmIdentifier and saves the result in |algor|. It returns one on
 // success, or zero on error.
 int x509_digest_sign_algorithm(EVP_MD_CTX *ctx, X509_ALGOR *algor);
 
diff --git a/crypto/x509/x509_test.cc b/crypto/x509/x509_test.cc
index c4fd0b8..6f08611 100644
--- a/crypto/x509/x509_test.cc
+++ b/crypto/x509/x509_test.cc
@@ -1789,7 +1789,8 @@
                            /*crit=*/0, /*flags=*/0);
 }
 
-static bool AddAuthorityKeyIdentifer(X509 *x509, bssl::Span<const uint8_t> key_id) {
+static bool AddAuthorityKeyIdentifier(X509 *x509,
+                                      bssl::Span<const uint8_t> key_id) {
   bssl::UniquePtr<AUTHORITY_KEYID> akid(AUTHORITY_KEYID_new());
   if (akid == nullptr) {
     return false;
@@ -1843,7 +1844,7 @@
   return true;
 }
 
-static bool AddAuthorityKeyIdentifer(X509_CRL *crl,
+static bool AddAuthorityKeyIdentifier(X509_CRL *crl,
                                      bssl::Span<const uint8_t> key_id) {
   bssl::UniquePtr<AUTHORITY_KEYID> akid(AUTHORITY_KEYID_new());
   if (akid == nullptr) {
@@ -8429,11 +8430,11 @@
   bssl::UniquePtr<X509> leaf1 =
       MakeTestCert("CA", "Leaf", key1.get(), /*is_ca=*/false);
   ASSERT_TRUE(leaf1);
-  ASSERT_TRUE(AddAuthorityKeyIdentifer(leaf1.get(), key_id1));
+  ASSERT_TRUE(AddAuthorityKeyIdentifier(leaf1.get(), key_id1));
   ASSERT_TRUE(X509_sign(leaf1.get(), key1.get(), EVP_sha256()));
   bssl::UniquePtr<X509_CRL> crl1 = MakeTestCRL("CA", -1, 1);
   ASSERT_TRUE(crl1);
-  ASSERT_TRUE(AddAuthorityKeyIdentifer(crl1.get(), key_id1));
+  ASSERT_TRUE(AddAuthorityKeyIdentifier(crl1.get(), key_id1));
   ASSERT_TRUE(X509_CRL_sign(crl1.get(), key1.get(), EVP_sha256()));
   // TODO(davidben): Some state in CRLs does not get correctly set up unless it
   // is parsed from data. |X509_CRL_sign| should reset it internally.
@@ -8451,11 +8452,11 @@
   bssl::UniquePtr<X509> leaf2 =
       MakeTestCert("CA", "Leaf", key2.get(), /*is_ca=*/false);
   ASSERT_TRUE(leaf2);
-  ASSERT_TRUE(AddAuthorityKeyIdentifer(leaf2.get(), key_id2));
+  ASSERT_TRUE(AddAuthorityKeyIdentifier(leaf2.get(), key_id2));
   ASSERT_TRUE(X509_sign(leaf2.get(), key2.get(), EVP_sha256()));
   bssl::UniquePtr<X509_CRL> crl2 = MakeTestCRL("CA", -2, 2);
   ASSERT_TRUE(crl2);
-  ASSERT_TRUE(AddAuthorityKeyIdentifer(crl2.get(), key_id2));
+  ASSERT_TRUE(AddAuthorityKeyIdentifier(crl2.get(), key_id2));
   ASSERT_TRUE(X509_CRL_sign(crl2.get(), key2.get(), EVP_sha256()));
   // TODO(davidben): Some state in CRLs does not get correctly set up unless it
   // is parsed from data. |X509_CRL_sign| should reset it internally.
diff --git a/include/openssl/ssl.h b/include/openssl/ssl.h
index d73f9da..49fb47e 100644
--- a/include/openssl/ssl.h
+++ b/include/openssl/ssl.h
@@ -3987,7 +3987,7 @@
 // to the size of the buffer. The caller must call |OPENSSL_free| on |*out| to
 // release the memory. On failure, it returns zero.
 //
-// The |config_id| field is a single byte identifer for the ECHConfig. Reusing
+// The |config_id| field is a single byte identifier for the ECHConfig. Reusing
 // config IDs is allowed, but if multiple ECHConfigs with the same config ID are
 // active at a time, server load may increase. See
 // |SSL_ECH_KEYS_has_duplicate_config_id|.
diff --git a/include/openssl/x509.h b/include/openssl/x509.h
index 7d4952f..0bff5c3 100644
--- a/include/openssl/x509.h
+++ b/include/openssl/x509.h
@@ -254,9 +254,9 @@
 // should not be accepted.
 #define EXFLAG_CRITICAL 0x200
 // EXFLAG_SS indicates the certificate is likely self-signed. That is, if it is
-// self-issued, its authority key identifer (if any) matches itself, and its key
-// usage extension (if any) allows certificate signatures. The signature itself
-// is not checked in computing this bit.
+// self-issued, its authority key identifier (if any) matches itself, and its
+// key usage extension (if any) allows certificate signatures. The signature
+// itself is not checked in computing this bit.
 #define EXFLAG_SS 0x2000
 
 // X509_get_extension_flags decodes a set of extensions from |x509| and returns
diff --git a/pki/signature_algorithm.h b/pki/signature_algorithm.h
index 2d65be2..be654fc 100644
--- a/pki/signature_algorithm.h
+++ b/pki/signature_algorithm.h
@@ -71,7 +71,7 @@
 [[nodiscard]] bool ParseHashAlgorithm(der::Input input, DigestAlgorithm *out);
 
 // Parses an AlgorithmIdentifier into a signature algorithm and returns it, or
-// returns `std::nullopt` if `algorithm_identifer` either cannot be parsed or
+// returns `std::nullopt` if `algorithm_identifier` either cannot be parsed or
 // is not a recognized signature algorithm.
 OPENSSL_EXPORT std::optional<SignatureAlgorithm> ParseSignatureAlgorithm(
     der::Input algorithm_identifier);
diff --git a/ssl/test/runner/handshake_client.go b/ssl/test/runner/handshake_client.go
index eecb114..0c338d7 100644
--- a/ssl/test/runner/handshake_client.go
+++ b/ssl/test/runner/handshake_client.go
@@ -521,7 +521,7 @@
 		channelIDSupported:        c.config.ChannelID != nil,
 		extendedMasterSecret:      maxVersion >= VersionTLS10,
 		srtpProtectionProfiles:    c.config.SRTPProtectionProfiles,
-		srtpMasterKeyIdentifier:   c.config.Bugs.SRTPMasterKeyIdentifer,
+		srtpMasterKeyIdentifier:   c.config.Bugs.SRTPMasterKeyIdentifier,
 		customExtension:           c.config.Bugs.CustomExtension,
 		omitExtensions:            c.config.Bugs.OmitExtensions,
 		emptyExtensions:           c.config.Bugs.EmptyExtensions,
diff --git a/ssl/test/runner/runner.go b/ssl/test/runner/runner.go
index 8cc698b..70cb520 100644
--- a/ssl/test/runner/runner.go
+++ b/ssl/test/runner/runner.go
@@ -8331,7 +8331,7 @@
 						MaxVersion:             ver.version,
 						SRTPProtectionProfiles: []uint16{SRTP_AES128_CM_HMAC_SHA1_80},
 						Bugs: ProtocolBugs{
-							SRTPMasterKeyIdentifer: "bogus",
+							SRTPMasterKeyIdentifier: "bogus",
 						},
 					},
 					flags: []string{
diff --git a/util/fipstools/delocate/delocate.go b/util/fipstools/delocate/delocate.go
index cd08bed..063d6ac 100644
--- a/util/fipstools/delocate/delocate.go
+++ b/util/fipstools/delocate/delocate.go
@@ -35,7 +35,7 @@
 // inputFile represents a textual assembly file.
 type inputFile struct {
 	path string
-	// index is a unique identifer given to this file. It's used for
+	// index is a unique identifier given to this file. It's used for
 	// mapping local symbols.
 	index int
 	// isArchive indicates that the input should be processed as an ar
diff --git a/ssl/test/runner/common.go b/ssl/test/runner/common.go
index f85a81a..082efce 100644
--- a/ssl/test/runner/common.go
+++ b/ssl/test/runner/common.go
@@ -1180,10 +1180,10 @@
 	// RSA_EXPORT) in the plain RSA key exchange.
 	RSAEphemeralKey bool
 
 	// SRTPMasterKeyIdentifer, if not empty, is the SRTP MKI value that the
 	// client offers when negotiating SRTP. MKI support is still missing so
 	// the peer must still send none.
-	SRTPMasterKeyIdentifer string
+	SRTPMasterKeyIdentifier string
 
 	// SendSRTPProtectionProfile, if non-zero, is the SRTP profile that the
 	// server sends in the ServerHello instead of the negotiated one.
@@ -1180,10 +1180,10 @@
 	RSAEphemeralKey bool
 
-	// SRTPMasterKeyIdentifer, if not empty, is the SRTP MKI value that the
+	// SRTPMasterKeyIdentifier, if not empty, is the SRTP MKI value that the
 	// client offers when negotiating SRTP. MKI support is still missing so
 	// the peer must still send none.